# TL - Timeline Figures

TL is a command line tool to create beautiful Timeline figures for clinical studies.

The input describing the study design is expected as a json- or yaml-formatted text file.

The output is provided in vector graphic form (as a .svg file) that can be easily included in Office documents or websites.
